@@ -8,11 +8,11 @@ curmonyear = datetime.datetime(curyear, curmon, 1)
 curmonyear_str = '{}-{}'.format(curyear, curmon) # get pandas time filtering
 
 
-"""
-Given a dataframe find the years in the column headings. Return a dict of colname to year
-eg { 'Q1 2016' : 2016, 'Q1 2017' : 2017
-"""
 def find_year(df, use_delta=False):
+    """
+    Given a dataframe find the years in the column headings. Return a dict of colname to year
+    eg { 'Q1 2016' : 2016, 'Q1 2017' : 2017
+    """
     res = {}
     for colname in df:
         colregex = re.findall('\d\d\d\d', str(colname))
@@ -21,7 +21,7 @@ def find_year(df, use_delta=False):
 
         res[colname] = colyear
         if use_delta:
-            delta = colyear - dates.curyear
+            delta = colyear - curyear
             res[colname] = delta
 
     return res
